// CopyFileThread.h
//
// Declaration of the CopyFileThread class.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#pragma once

// TTFS
#include "TTFS_API.h"

// TomTomSupporterBase
#include "RegisteredThread.h"

class QByteArray;
class IProgressReporter;
class IPackageValidator;

class CopyFileThread : public RegisteredThread
{
    Q_OBJECT

public:
    CopyFileThread(const QString& aFilePath, const QString& aFolder,
        IProgressReporter* aReporter = 0, IPackageValidator* aValidator = 0,
        QObject* aParent = 0);
    virtual ~CopyFileThread();

    // The next enum enumerates all error codes that are returned from CopyFileThread.
    enum Error 
    {
        _errUNDEF = 0,                      // For internal use only. Must be 0!
        _errMIN,                            // For internal use only.
        errSourceFileDoesNotExist,          // Source file does not exist.
        errTargetFileAlreadyExists,         // Target file already exists.
        errUnableToWriteAllData,            // Unable to write all the data.
        errInvalidData,                     // Invalid data.
        errUnableToOpenFileForWriting,      // Unable to open file for writing.
        errNotEnoughSpaceAvailable,         // Not enough space available.
        _errMAX                             // For internal use only.
    };
    
    static QString TTFS_API GetErrorString(Error aError);

    Error GetLastError() const;
    
protected:
    // overrides:
    void run();
    
private:
    QString iFilePath;
    QString iFolder;
    IProgressReporter* iReporter;
    IPackageValidator* iValidator;
    Error iError;
};
