# TTFS.pro
#
# Project file to generate projects fo Visual Studio 2010 and XCode 4.3
#
# The MIT License (MIT)
# Copyright © 2012 TomTom International B.V.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
# documentation files (the “Software”), to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
# to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
# THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
# CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.

TARGET = TTFS
DEPENDPATH += . debug release
DEFINES += TTFS_EXPORTS
QT -= gui # Only the core module is used.

INCLUDEPATH += ../EXT2FSLib/e2fsprogs-1.41.14/lib
INCLUDEPATH += ../EXT2FSLib
INCLUDEPATH += ../TomTomSupporterBase

win32 {
    TEMPLATE = vclib
    LIBS += ext2fs.lib
    LIBS += TomTomSupporterBase.lib
    CONFIG += dll
    QMAKE_LFLAGS_DEBUG += /PDB:"Debug/TTFS.pdb" /Debug /MAP:"Debug/TTFS.map"
    QMAKE_LFLAGS_DEBUG += /LIBPATH:../Debug
    QMAKE_LFLAGS_DEBUG += /LIBPATH:../EXT2FSLib/ext2fs/Debug
    QMAKE_LFLAGS_DEBUG += /LIBPATH:../TomTomSupporterBase/Debug
    QMAKE_LFLAGS_RELEASE += /PDB:"Release/TTFS.pdb" /Debug /MAP:"Release/TTFS.map"
    QMAKE_LFLAGS_RELEASE += /LIBPATH:../Release
    QMAKE_LFLAGS_RELEASE += /LIBPATH:../EXT2FSLib/ext2fs/Release
    QMAKE_LFLAGS_RELEASE += /LIBPATH:../TomTomSupporterBase/Release
}
macx {
    TEMPLATE = lib
    # OS106 is use current OS SDK and deployment 10.5
    QMAKE_MACOSX_DEPLOYMENT_TARGET = 10.5
    # remove the debug and release configuration as the mac will
    # only produce one configuartion, by default debug

    CONFIG += $$[TTSA_CONFIG]
	CONFIG(Debug) {	
    	CONFIG -= Debug
    	CONFIG -= release
    }
    CONFIG(Release) {	
    	CONFIG -= Release
    	CONFIG -= debug
    	CONFIG += release
    }
    CONFIG(Coverage) {
        CONFIG -= Coverage
        CONFIG -= release
        message(Coverage is in effect!)
        QMAKE_CXXFLAGS += -fprofile-arcs -ftest-coverage
        QMAKE_LFLAGS += -lgcov
    }

    CONFIG += $$[TTSA_MACOS]
    
    CONFIG(release, debug|release):message(Release build!)
 	CONFIG(debug, debug|release):message(Debug build!) 
    
    CONFIG += x86
    CONFIG -= ppc
    
    # switch between Mac 10.5 and 10.6/7
    CONFIG(OS106) {	
    	CONFIG -= OS106
    	message(build deployment target 10.5 current OS SDK!)
   	
    	debug {
    		QMAKE_LFLAGS += -L../EXT2FSLib/build/Debug
    	}
    	release {
     		QMAKE_LFLAGS += -L../EXT2FSLib/build/Release
    	}
    }
    CONFIG(OS105) {
    	CONFIG -= OS105
    	message(OS 10.5 SDK build!)
    	QMAKE_MACOSX_DEPLOYMENT_TARGET = 10.5
        QMAKE_MAC_SDK=/Developer/SDKs/MacOSX10.5.sdk
        
        debug {
    		QMAKE_LFLAGS += -L../EXT2FSLib/build/Debug105
    	}
    	release {
     		QMAKE_LFLAGS += -L../EXT2FSLib/build/Release105
    	}
    }
    debug {
        QMAKE_LFLAGS += -L../TomTomSupporterBase/build/Debug
    }
    release {
        QMAKE_LFLAGS += -L../TomTomSupporterBase/build/Release
    }
    LIBS += -lext2fs
    LIBS += -lTomTomSupporterBase
}
else:unix {
    TEMPLATE = lib
    DEFINES += kLinux=1
    CONFIG += debug_and_release
#    QMAKE_CXXFLAGS += -g
    LIBS += -lext2fs
    LIBS += -lcom_err
    LIBS += -lTomTomSupporterBase
    QMAKE_LFLAGS += -L../TomTomSupporterBase
    QMAKE_LFLAGS += -L../EXT2FSLib/e2fsprogs-1.41.14/build/lib
}

# Input
HEADERS += \
    CopyFileThread.h \
    FileSystemInfo.h \
    GetDeviceSize.h \
    TTFSDebug.h \
    TTFSLogger.h \
    TTFSLoggerStream.h \
    TTFSDir.h \
    TTFSError.h \
    TTFSFile.h \
    TTFSFileEngine.h \
    TTFSFileEngineHandler.h \
    TTFSFileEngineIterator.h \
    TTFSFileInfo.h \
    TTFSFileSystem.h \
    TTFSFileSystemManager.h \
    TTFSIO.h \
    TTFSLookupEntry.h \
    TTFSNode.h \
    TTFSTypes.h \
    TTFS_API.h

SOURCES += \
    CopyFileThread.cpp \
    FileSystemInfo.cpp \
    GetDeviceSize.cpp \
    TTFSDebug.cpp \
    TTFSLoggerStream.cpp \
    TTFSDir.cpp \
    TTFSError.cpp \
    TTFSFile.cpp \
    TTFSFileEngine.cpp \
    TTFSFileEngineHandler.cpp \
    TTFSFileEngineIterator.cpp \
    TTFSFileInfo.cpp \
    TTFSFileSystem.cpp \
    TTFSFileSystemManager.cpp \
    TTFSIO.cpp \
    TTFSNode.cpp
