// TTFSDebug.cpp
//
// TTFSDebug provides functionality debugging capabilities based on
// QtDebug, for debugging TTFS.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#include "TTFSDebug.h"

// Qt
#include <QtCore>
#include <QtDebug>


// -----------------------------------------------------------------------------
// STATIC VARIABLES
// -----------------------------------------------------------------------------

static TTFS::SpyLevel sCurrentSpyLevel = TTFS::spylevelINFO;



// -----------------------------------------------------------------------------
// PUBLIC FUNCTIONS
// -----------------------------------------------------------------------------

TTFS::SpyLevel TTFS::spyLevel()
{
    return sCurrentSpyLevel;
}



void TTFS::SetSpyLevel(SpyLevel level)
{
    Q_ASSERT((TTFS::_spylevelMIN < level) && (level < TTFS::_spylevelMAX));
    sCurrentSpyLevel = level;
}



// -----------------------------------------------------------------------------
// DEBUG FUNCTIONS
// -----------------------------------------------------------------------------

#ifndef QT_NO_DEBUG

class TTFSCheckSpyActive
{
public:
    TTFSCheckSpyActive();   // This class is only used to show the Spy level
    ~TTFSCheckSpyActive();  // once you start the application. See sCheckSpyActive.
};



TTFSCheckSpyActive::TTFSCheckSpyActive()
{
    const char* sMethodName = "TTFSCheckSpyActive::TTFSCheckSpyActive";
    // Check the validity of the error string list once.
    static bool done = false;
    if (!done)
    {
        done = true;
        switch (sCurrentSpyLevel)
        {
        case TTFS::spylevelOFF:
            Logger::LogInformation(sMethodName, "[INFO] Spy level: OFF, no messages are output");
            break;
        case TTFS::spylevelFAIL:
            Logger::LogInformation(sMethodName, "[INFO] Spy level: FAIL, only failures are output");
            break;
        case TTFS::spylevelWARN:
            Logger::LogInformation(sMethodName, "[INFO] Spy level: WARN, warnings and failures are output");
            break;
        case TTFS::spylevelINFO:
            Logger::LogInformation(sMethodName, "[INFO] Spy level: INFO, informationals, warnings and failures are output");
            break;
        default:
            Q_ASSERT(false);
            spyINFO("");            // Add some macros here for easy checking
            spyWARN("" << 1);       // of correct definition of macros during compilation.
            spyFAIL(0, 1 << "");       // These should never called.
            break;
        }
    }
}



TTFSCheckSpyActive::~TTFSCheckSpyActive()
{
    ; // Empty.
}



// Declare a static instance of TTFSCheckSpyActive. The ctor will 
// show the soy level.
//
static const TTFSCheckSpyActive sCheckSpyActive;   

#endif //QT_NO_DEBUG

