// TTFSFileEngineHandler.cpp
//
// Implementation of the TTFSFileEngineHandler class.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#include "TTFSFileEngineHandler.h"

// TTFS (this software library)
#include "TTFSFileEngine.h"

// Qt
#include <QtCore>
#include <QAbstractFileEngineHandler>


// -----------------------------------------------------------------------------
// STATIC OBJECTS
// -----------------------------------------------------------------------------

// ttfs := TomTomFileSystem
// Declares the global static variables across the library/executable. 
// The Qt uses this method to define the only one instance of Qt QResourceFileEngine.   
Q_GLOBAL_STATIC(TTFSFileEngineHandler, ttfs_engine_handler);

static int qt_force_ttfs_init()
{
    ttfs_engine_handler();
    return 1;
}

static int qt_forced_ttfs_init = qt_force_ttfs_init();

Q_CONSTRUCTOR_FUNCTION(qt_force_ttfs_init)

// -----------------------------------------------------------------------------
// PUBLIC MEMBER FUNCTIONS
// -----------------------------------------------------------------------------

TTFSFileEngineHandler::TTFSFileEngineHandler() :
    QAbstractFileEngineHandler()
{
    Q_ASSERT(isValid());

    ; // No initialization required. Performed by base class.
}

TTFSFileEngineHandler::~TTFSFileEngineHandler()
{
    Q_ASSERT(isValid());
}

QAbstractFileEngine* TTFSFileEngineHandler::create(const QString& fileName) const
{
    QAbstractFileEngine* fileEngine = 0;

    // Check if the file can be handled by a TTFS file system engine.
    if (TTFSFileEngine::canHandle(fileName))
    {
        // Create a new file system engine object.
        fileEngine = new TTFSFileEngine(fileName);
        Q_ASSERT(fileEngine);
    }
    return fileEngine;
}

#ifndef QT_NO_DEBUG
bool TTFSFileEngineHandler::isValid() const
{
    bool isOk = true;
    return isOk;        // Empty check for now.
}
#endif
