// TTFSFileEngineHandler.h
//
// The TTFSFileEngineHandler class is used by Qt to create a 
// QAbstractFileEngine for a specific file on a TTFS file system.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#pragma once

// Qt
#include <QAbstractFileEngineHandler>


class TTFSFileEngineHandler : public QAbstractFileEngineHandler
{
public:
    TTFSFileEngineHandler();
    ~TTFSFileEngineHandler();

    // Create a TTFSFileEngine for a particular pathname (or return 0
    // if the file is not handled by TTFS).
    virtual QAbstractFileEngine* create(const QString& fileName) const;

// Unsupported operations.
private:
    TTFSFileEngineHandler(const TTFSFileEngineHandler&);                    // Unsupported.
    const TTFSFileEngineHandler& operator=(const TTFSFileEngineHandler&);   // Unsupported.

// Debug functions.
public:
#ifndef QT_NO_DEBUG
    bool isValid() const;
#endif
};
