// TTFSFileEngineIterator.cpp
//
// Implementation of the TTFSFileEngineIterator class.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#include "TTFSFileEngineIterator.h"

// TTFS (this software library)
#include "TTFSDir.h"



static const int kInvalidIndex = -1;

TTFSFileEngineIterator::TTFSFileEngineIterator(QDir::Filters aFilters,
    const QStringList& aNameFilters) :
    QAbstractFileEngineIterator(aFilters, aNameFilters),
    iIndex(kInvalidIndex),
    iFirstRun(true)
{
    Q_ASSERT(isValid());
}



TTFSFileEngineIterator::~TTFSFileEngineIterator()
{
    Q_ASSERT(isValid());
}



QString TTFSFileEngineIterator::next()
{
    if (!hasNext())
    {
        return QString();
    }
    ++iIndex;
    return currentFileName();
}



bool TTFSFileEngineIterator::hasNext() const
{
    if (iFirstRun)
    {
        iFirstRun = false;

        TTFSDir theDir(path());
        iDirEntries = theDir.entryList();

        iIndex = kInvalidIndex;
    }
    return (iIndex < iDirEntries.length() + kInvalidIndex);
}



QString TTFSFileEngineIterator::currentFileName() const
{
    return iDirEntries.at(iIndex).GetFilename();
}



#ifndef QT_NO_DEBUG
bool TTFSFileEngineIterator::isValid() const
{
    bool isOk = true;
    Q_ASSERT(isOk = isOk && (kInvalidIndex == kInvalidIndex || iIndex <= (iDirEntries.size())));
    return isOk;
}
#endif
