// TTFSFileEngineIterator.h
//
// This class provides an iterator over files for abstract file engine
// class: QAbstractFileEngineIterator.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#pragma once

// TTFS
#include "TTFSFileInfo.h"

// Qt
#include <QAbstractFileEngineIterator>



class TTFSFileEngineIterator : public QAbstractFileEngineIterator
{
public:
    TTFSFileEngineIterator(
        QDir::Filters aFilters,                     // File aatribute filters.
        const QStringList& aNameFilters);           // File name filters.
    virtual ~TTFSFileEngineIterator();

    virtual QString     next();                     // Proceed to next and return filename.
    virtual bool        hasNext() const;            // Is there a next filename?
    virtual QString     currentFileName() const;    // Return current filename.

// Unsupported member functions.
private:
    TTFSFileEngineIterator();                                           // Not supported.
    TTFSFileEngineIterator(const TTFSFileEngineIterator&);              // Not supported.
    TTFSFileEngineIterator& operator=(const TTFSFileEngineIterator&);   // Not supported.

// Data members.
private:
    mutable int              iIndex;         // The current index of the iterator.
    mutable TTFSFileInfoList iDirEntries;    // The list of the directory entry names.
    mutable bool             iFirstRun;      // Lazy initialization

// Debug functions.
public:
#ifndef QT_NO_DEBUG
    bool isValid() const;
#endif
};
