// TTFSLoggerStream.cpp
//
// TTFSLoggerStream provides functionality to output the information 
// to QString.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#include "TTFSLoggerStream.h"

TTFSLoggerStream::TTFSLoggerStream(QString* aString, bool aSpace/* = true*/)
    : iStream(aString, QIODevice::WriteOnly),
    iSpace(aSpace)
{
    ; // empty
}

TTFSLoggerStream::~TTFSLoggerStream()
{
    ; // empty
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (QChar aCh)
{
    iStream << aCh;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (signed short aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (float aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (const QString& aString)
{
    iStream << aString;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (char aCh)
{
    iStream << aCh;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (unsigned short aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (signed int aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (unsigned int aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (signed long aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (unsigned long aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (qlonglong aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (qulonglong aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (double aVal)
{
    iStream << aVal;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (const QByteArray& aArray)
{
    iStream << aArray;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (const char* aString)
{
    iStream << aString;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::operator<< (const void* aPtr)
{
    iStream << aPtr;
    return AddSpace();
}

TTFSLoggerStream& TTFSLoggerStream::AddSpace()
{
    if (iSpace)
    {
        iStream << ' ';
    }
    return *this;
}

