// TTFSLoggerStream.h
//
// TTFSLoggerStream provides functionality to output the information 
// to QString.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#pragma once

// Qt
#include <QString>
#include <QTextStream>

class TTFSLoggerStream
{
public:
    TTFSLoggerStream(QString* aString, bool aSpace = true);
    ~TTFSLoggerStream();

    // QTextStream interface to output value to stream. 
    TTFSLoggerStream& operator<< (QChar aCh);
    TTFSLoggerStream& operator<< (signed short aVal);
    TTFSLoggerStream& operator<< (float aVal);
    TTFSLoggerStream& operator<< (const QString& aString);
    TTFSLoggerStream& operator<< (char aCh);
    TTFSLoggerStream& operator<< (unsigned short aVal);
    TTFSLoggerStream& operator<< (signed int aVal);
    TTFSLoggerStream& operator<< (unsigned int aVal);
    TTFSLoggerStream& operator<< (signed long aVal);
    TTFSLoggerStream& operator<< (unsigned long aVal);
    TTFSLoggerStream& operator<< (qlonglong aVal);
    TTFSLoggerStream& operator<< (qulonglong aVal);
    TTFSLoggerStream& operator<< (double aVal);
    TTFSLoggerStream& operator<< (const QByteArray& aArray);
    TTFSLoggerStream& operator<< (const char* aString);
    TTFSLoggerStream& operator<< (const void* aPtr);

private:
    TTFSLoggerStream();                          ///< Prevent default ctor().
    TTFSLoggerStream(const TTFSLoggerStream& );  ///< Prevent copy ctor().

    TTFSLoggerStream& AddSpace();

private:
    QTextStream iStream;    ///< Target output stream.
    bool iSpace;            ///< Add space after output value.
};
