// TTFSTypes.h
//
// TTFSTypes provides a couple of enumeration types used in the TTFS
// library.
//
// The MIT License (MIT)
// Copyright © 2012 TomTom International B.V.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
// documentation files (the “Software”), to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
// to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of
// the Software.
//
// THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#pragma once

class QString;

// Declare a namespace for all TTFS types, so all identifiers can
// be specified as "TTFS::<name>".
namespace TTFS
{
    extern const QString ContainerFileName;

    // TTFSOpenMode specifies a file open mode for files
    // in a TTFS file system.
    enum OpenMode
    {
        _omUNDEF    = -2,                   // For internal use only.
        _omMIN      = -1,                   // For internal use only.
        omStat      = 0,                    // Allow stat.
        omRead      = 1,                    // Allow read.
        omWrite     = 2,                    // Allow write.
        omReadWrite = omRead | omWrite,     // Allow read/write.
        omAppend    = 4 | omWrite,          // Allow append.
        _omMAX      = 8                     // For internal use only.
    };


    // TTFSFileType specifies a file type for files in
    // a TTFS file syste,
    enum FileType
    {
        _ftUNDEF               = -2,        // For internal use only.
        _ftMIN                 = -1,        // For internal use only.
        ftUnknown              = 0,
        ftRegularFile          = 1,
        ftDirectory            = 2,
        ftChrDev               = 3,
        ftBlkDev               = 4,
        ftFifo                 = 5,
        ftSocket               = 6,
        ftSymlink              = 7,
        _ftMAX                 = 8          // For internal use only.
    };
};
